WideGhashProduct

Struct WideGhashProduct 

pub struct WideGhashProduct<U: Underlier128bLanes> { /* private fields */ }
An unreduced GHASH product, stored as the four 64-bit limbs (v0, v1, v2, v3) of the 256-bit schoolbook product. Values of this type can be summed by XOR and reduced once at the end via reduce.

Implementations

Source

impl<U: Underlier128bLanes> WideGhashProduct<U>

pub fn reduce(self) -> U

Reduce the accumulated wide product to a single GF(2^128) element.